# Teaching Tools

Run `python generate_notebook.py` in your terminal and let the magic happen

The script connects to an S3 bucket with the questions. Those questions are stored usign the lesson id, and in order to get those ids, it connects to an RDS to make a query to check it.